import pyquery
import click
import requests
from requests.auth import HTTPBasicAuth


@click.command('domain')
@click.option('--ssl/--no-ssl', is_flag=True, help="Test/Don't test https", default=True)
@click.option('--www/--no-www', is_flag=True, help="Test/Don't prepend www", default=True)
@click.option('--user', '-u', help="The user for basic authentication")
@click.option('--password', '-p', help="The pass for basic authentication")
@click.argument('domains', nargs=-1)
def test_response(ssl, www, user, password, domains):
    "Test response from servers"
    protocols = ['http']
    if ssl:
        protocols += ['https']
    prefixes = ['']
    if www:
        prefixes +=  ['www.']
    if isinstance(domains, basestring):
        domains = [domains]
    for domain in domains:
        for proto in protocols:
            for prefix in prefixes:
                url = u"{proto}://{prefix}{domain}".format(**locals())
                test_url(url, user, password)


def test_url(url, user=None, password=None):
    if user:
        auth = HTTPBasicAuth(user, password)
    else:
        auth = None
    try:
        resp = requests.get(url, auth=auth, allow_redirects=False)
    except requests.exceptions.ConnectionError:
        print(u"{}: connection FAILED".format(url))
        return

    if resp.status_code >= 300 and resp.status_code < 400:
        Location = resp.headers['Location']
        print(u"{url} => {resp.status_code}  ({Location})".format(
            **locals()))
    elif resp.status_code >= 200 and resp.status_code < 300:
        d = pyquery.PyQuery(resp.content)
        title = (d('title').contents()[0]).strip()

        msg = u"{url} => {resp.status_code} ({title})".format(**locals())
        click.echo(click.style(msg, fg='green'))
    else:
        msg = u"{url} {resp}".format(url=url, resp=resp.json)
        click.echo(click.style(url, fg='red'))
